@@ -305,6 +305,20 @@ class CheckovTool(ToolGateway):
         # Crea una lista para almacenar los hilos
         threads = []
         rules_run = {}
+        
+        # Incluir reglas adicionales para serverless si se especifica en la configuración SERVERLESS_ADITIONAL_CHECKS
+        ADDITIONAL_CHECKS = config_tool[self.TOOL_CHECKOV].get("SERVERLESS_ADITIONAL_CHECKS", [])
+        if any(p.lower() in ["serverless", "all"] for p in platform_to_scan) and ADDITIONAL_CHECKS:
+            for additional_check_type in ADDITIONAL_CHECKS:
+                config_tool[self.TOOL_CHECKOV]["RULES"]["RULES_SERVERLESS"].update(config_tool[self.TOOL_CHECKOV]["RULES"][additional_check_type])
+                
+        # Configurar LOG_LEVEL si está definido
+        log_level = config_tool[self.TOOL_CHECKOV].get("LOG_LEVEL")
+        if log_level:
+            if agent_env is None:
+                agent_env = {}
+            agent_env["LOG_LEVEL"] = log_level
+        
         for folder in folders_to_scan:
             for rule in config_tool[self.TOOL_CHECKOV]["RULES"]:
                 if "all" in platform_to_scan or any(
@@ -403,7 +417,6 @@ class CheckovTool(ToolGateway):
             + checkov_config.path_config_file
             + checkov_config.config_file_name
             + self.CHECKOV_CONFIG_FILE
-            + " --quiet"
         )
         env_modified = dict(os.environ)
         if checkov_config.env is not None:
